@@ -27,7 +27,6 @@
 
 #include <inttypes.h>
 #include <stdio.h>
-#include <sys/types.h>
 #include "mmsio.h"
 
 #ifdef __cplusplus
@@ -41,20 +40,21 @@ mmsh_t*   mmsh_connect (mms_io_t *io, void *data, const char *url_, int bandwidt
 
 int      mmsh_read (mms_io_t *io, mmsh_t *instance, char *data, int len);
 int      mmsh_time_seek (mms_io_t *io, mmsh_t *instance, double time_sec);
-mms_off_t mmsh_seek (mms_io_t *io, mmsh_t *this, mms_off_t offset, int origin);
+mms_off_t mmsh_seek (mms_io_t *io, mmsh_t *instance, mms_off_t offset, int origin);
 uint32_t mmsh_get_length (mmsh_t *instance);
-double   mmsh_get_time_length (mmsh_t *this);
-uint64_t mmsh_get_raw_time_length (mmsh_t *this);
+double   mmsh_get_time_length (mmsh_t *instance);
+uint64_t mmsh_get_raw_time_length (mmsh_t *instance);
+uint64_t mmsh_get_file_time (mmsh_t *instance);
 mms_off_t mmsh_get_current_pos (mmsh_t *instance);
 void     mmsh_close (mmsh_t *instance);
 
 int      mmsh_peek_header (mmsh_t *instance, char *data, int maxsize);
 
-uint32_t mmsh_get_asf_header_len (mmsh_t *this);
+uint32_t mmsh_get_asf_header_len (mmsh_t *instance);
 
-uint32_t mmsh_get_asf_packet_len (mmsh_t *this);
+uint32_t mmsh_get_asf_packet_len (mmsh_t *instance);
 
-int      mmsh_get_seekable (mmsh_t *this);
+int      mmsh_get_seekable (mmsh_t *instance);
 
 #ifdef __cplusplus
 }
