@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 Hans de Goede <j.w.r.degoede@hhs.nl>
+ * Copyright (C) 2007 Hans de Goede <j.w.r.degoede@gmail.com>
  *
  * This file is part of libmms a free mms protocol library
  *
@@ -109,6 +109,13 @@ uint64_t mmsx_get_raw_time_length (mmsx_t *mmsx)
     return mmsh_get_raw_time_length(mmsx->connection_h);
 }
 
+uint64_t mmsx_get_file_time (mmsx_t *mmsx) {
+  if(mmsx->connection)
+    return mms_get_file_time(mmsx->connection);
+  else
+    return mmsh_get_file_time(mmsx->connection_h);
+}
+
 uint32_t mmsx_get_length (mmsx_t *mmsx)
 {
   if(mmsx->connection)
