@@ -115,27 +115,27 @@ for ($i = 0; $i < 32; $i++)
 
 static int split_user_passwd(const char* in, char** user, char** passwd)
 {
-  char *tmp = strdup(in);
+  char *pass, *tmp = g_strdup(in);
+  int ret = 0;
 
   if(!tmp)
     return 0;
-  *passwd = strchr(tmp, ':');
-  if(!(*passwd))
-  {
-    free(tmp);
-    return 0;
-  }
-  *((*passwd)++) = '\0'; // don't you love C? :)
 
-  *user = strdup(tmp);
-  if(!*user)
-    return 0;
-  *passwd = strdup(*passwd);
-  if(!*passwd)
-    return 0;
+  pass = strchr(tmp, ':');
+  if (!pass)
+    goto fail;
+  *pass = 0;
+  pass++;
 
-  free(tmp);
-  return 1;
+  *user = g_strdup(tmp);
+  *passwd = g_strdup(pass);
+
+  if (*user && *passwd)
+    ret = 1;
+
+fail:
+  g_free(tmp);
+  return ret;
 }
 
 /**
@@ -199,10 +199,10 @@ gnet_uri_new (const char* uri)
           userinfo = g_strndup (temp, p - temp);
           if(!split_user_passwd(userinfo, &guri->user, &guri->passwd))
           {
-            free(userinfo);
+            g_free(userinfo);
             goto error;
           }
-          free(userinfo);
+          g_free(userinfo);
           ++p;
         }
       else
